Encrust
==============================

Automate all the steps to add the flavorful, savory crust that macOS
applications written in Python require to launch, which is to say:

    - universal2 binaries
    - code signing
    - notarization
    - archiving

Run ``encrust configure`` for an explanation of how to set it up, then
``encrust release`` to run it.
